package ofxgo

// A list of all the leaf elements in OFX 1.0.3 (the last SGML version of the
// spec). These are all the elements that are possibly left unclosed, and which
// can have no children of their own. Fortunately these two sets of elements
// are the same. We use this list when parsing to remove ambiguities about
// element nesting.
//
// Generated using the following command with the 1.0.3 SPEC .dtd file:
//   # sed -rn 's/^<!ELEMENT\s+([A-Z]+)\s+-\s+o\s+%.*TYPE>.*$/\t"\1",/p' *.dtd | sort
var ofxLeafElements = []string{
	"ACCESSKEY",
	"ACCTID",
	"ACCTKEY",
	"ACCTREQUIRED",
	"ACCTTYPE",
	"ADJAMT",
	"ADJDATE",
	"ADJDESC",
	"ADJNO",
	"APPID",
	"APPVER",
	"AUTHTOKEN",
	"AUTHTOKENFIRST",
	"AUTHTOKENINFOURL",
	"AUTHTOKENLABEL",
	"AVAILACCTS",
	"BALAMT",
	"BALCLOSE",
	"BALMIN",
	"BALOPEN",
	"BALTYPE",
	"BANKID",
	"BILLREFINFO",
	"BRANCHID",
	"CANADDPAYEE",
	"CANBILLPAY",
	"CANCELWND",
	"CANEMAIL",
	"CANMODMDLS",
	"CANMODPMTS",
	"CANMODXFERS",
	"CANNOTIFY",
	"CANPENDING",
	"CANRECUR",
	"CANSCHED",
	"CANUSEDESC",
	"CANUSERANGE",
	"CASESEN",
	"CHARTYPE",
	"CHECKNUM",
	"CHGPINFIRST",
	"CHGUSERINFO",
	"CHKANDDEB",
	"CHKERROR",
	"CHKNUMEND",
	"CHKNUMSTART",
	"CHKSTATUS",
	"CITY",
	"CLIENTACTREQ",
	"CLIENTROUTING",
	"CLIENTUID",
	"CLIENTUIDREQ",
	"CLOSINGAVAIL",
	"CLTCOOKIE",
	"CODE",
	"CONFMSG",
	"CORRECTACTION",
	"CORRECTFITID",
	"COUNTRY",
	"CREDITLIMIT",
	"CSPHONE",
	"CURDEF",
	"CURRATE",
	"CURSYM",
	"DATEBIRTH",
	"DAYPHONE",
	"DAYSTOPAY",
	"DAYSWITH",
	"DEBADJ",
	"DEPANDCREDIT",
	"DESC",
	"DFLTDAYSTOPAY",
	"DIFFFIRSTPMT",
	"DIFFLASTPMT",
	"DOMXFERFEE",
	"DSCAMT",
	"DSCDATE",
	"DSCDESC",
	"DSCRATE",
	"DTACCTUP",
	"DTASOF",
	"DTAVAIL",
	"DTCHANGED",
	"DTCLIENT",
	"DTCLOSE",
	"DTCREATED",
	"DTDUE",
	"DTEND",
	"DTEXPIRE",
	"DTINFOCHG",
	"DTNEXT",
	"DTOPEN",
	"DTPMTDUE",
	"DTPMTPRC",
	"DTPOSTED",
	"DTPOSTEND",
	"DTPOSTSTART",
	"DTPROFUP",
	"DTPURCHASE",
	"DTSERVER",
	"DTSTART",
	"DTUSER",
	"DTXFERPRC",
	"DTXFERPRJ",
	"EMAIL",
	"EVEPHONE",
	"EXTDPMTCHK",
	"EXTDPMTFOR",
	"FAXPHONE",
	"FEE",
	"FEEMSG",
	"FICERTID",
	"FID",
	"FINALAMT",
	"FINAME",
	"FINCHG",
	"FIRSTNAME",
	"FITID",
	"FREQ",
	"FROM",
	"GENUSERKEY",
	"GETMIMESUP",
	"HASEXTDPMT",
	"IDSCOPE",
	"INCIMAGES",
	"INITIALAMT",
	"INTLXFERFEE",
	"INVALIDACCTTYPE",
	"INVDATE",
	"INVDESC",
	"INVNO",
	"INVPAIDAMT",
	"INVTOTALAMT",
	"LANGUAGE",
	"LASTNAME",
	"LITMAMT",
	"LITMDESC",
	"LOSTSYNC",
	"MAILSUP",
	"MAX",
	"MEMO",
	"MESSAGE",
	"MFACHALLENGEFIRST",
	"MFACHALLENGESUPT",
	"MFAPHRASEA",
	"MFAPHRASEID",
	"MFAPHRASELABEL",
	"MIDDLENAME",
	"MIN",
	"MINPMTDUE",
	"MKTGINFO",
	"MODELWND",
	"MODPENDING",
	"NAME",
	"NEWUSERPASS",
	"NINSTS",
	"NONCE",
	"OFXSEC",
	"ORG",
	"PAYACCT",
	"PAYANDCREDIT",
	"PAYEEID",
	"PAYEELSTID",
	"PAYINSTRUCT",
	"PHONE",
	"PINCH",
	"PMTBYADDR",
	"PMTBYPAYEEID",
	"PMTBYXFER",
	"PMTPRCCODE",
	"POSTALCODE",
	"POSTPROCWND",
	"PROCDAYSOFF",
	"PROCENDTM",
	"PURANDADV",
	"RECSRVRTID",
	"REFNUM",
	"REFRESH",
	"REFRESHSUPT",
	"REJECTIFMISSING",
	"RESPFILEER",
	"SECURITYNAME",
	"SESSCOOKIE",
	"SEVERITY",
	"SIC",
	"SIGNONREALM",
	"SPACES",
	"SPECIAL",
	"SPNAME",
	"SRVRTID",
	"STATE",
	"STPCHKFEE",
	"STSVIAMODS",
	"SUBJECT",
	"SUPTXDL",
	"SVC",
	"SVCSTATUS",
	"SYNCMODE",
	"TAN",
	"TAXID",
	"TEMPPASS",
	"TO",
	"TOKEN",
	"TOKENONLY",
	"TOTALFEES",
	"TOTALINT",
	"TRANSPSEC",
	"TRNAMT",
	"TRNTYPE",
	"TRNUID",
	"TSKEYEXPIRE",
	"TSPHONE",
	"URL",
	"USEHTML",
	"USERID",
	"USERKEY",
	"USERPASS",
	"VALUE",
	"VER",
	"XFERDAYSWITH",
	"XFERDEST",
	"XFERDFLTDAYSTOPAY",
	"XFERPRCCODE",
	"XFERSRC",
}
